=======
Qinling
=======

.. note::

   Qinling (is pronounced "tchinling") refers to Qinling Mountains in southern
   Shaanxi Province in China. The mountains provide a natural boundary between
   North and South China and support a huge variety of plant and wildlife, some
   of which is found nowhere else on Earth.

Qinling is Function as a Service for OpenStack. This project aims to provide a
platform to support serverless functions (like AWS Lambda). Qinling supports
different container orchestration platforms (Kubernetes/Swarm, etc.) and
different function package storage backends (local/Swift/S3) by nature using
plugin mechanism.

* Free software: under the `Apache license <https://www.apache.org/licenses/LICENSE-2.0>`_
* Documentation: https://docs.openstack.org/qinling/latest/
* Source: https://opendev.org/openstack/qinling
* Features: https://storyboard.openstack.org/#!/project/927
* Bug Track: https://storyboard.openstack.org/#!/project/927
* Release notes:  https://docs.openstack.org/releasenotes/qinling/
* IRC channel on Freenode: #openstack-qinling
